@@ -78,13 +78,17 @@ gtd_provider_eds_set_default (GtdProviderEds *self,
                               GtdTaskList    *list)
 {
   GtdProviderEdsPrivate *priv;
+  GtdManager *manager;
   ESource *source;
 
   priv = gtd_provider_eds_get_instance_private (self);
   source = gtd_task_list_eds_get_source (GTD_TASK_LIST_EDS (list));
+  manager = gtd_manager_get_default ();
 
-  gtd_manager_set_default_provider (gtd_manager_get_default (), GTD_PROVIDER (self));
   e_source_registry_set_default_task_list (priv->source_registry, source);
+
+  if (gtd_manager_get_default_provider (manager) != (GtdProvider*) self)
+    gtd_manager_set_default_provider (manager, GTD_PROVIDER (self));
 }
 
 static void
@@ -134,7 +138,9 @@ gtd_provider_eds_fill_task_list (GObject      *client,
 
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error fetching tasks from list"),
-                                      error->message);
+                                      error->message,
+                                      NULL,
+                                      NULL);
       g_error_free (error);
       return;
     }
@@ -171,7 +177,9 @@ gtd_provider_eds_on_client_connected (GObject      *source_object,
 
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Failed to connect to task list"),
-                                      error->message);
+                                      error->message,
+                                      NULL,
+                                      NULL);
 
       g_error_free (error);
       return;
@@ -420,7 +428,7 @@ default_tasklist_changed_cb (ESourceRegistry *source_registry,
   list = g_object_get_data (G_OBJECT (default_source), "task-list");
 
   /* The list might not be loaded yet */
-  if (!list)
+  if (!list || gtd_task_list_get_provider (list) != (GtdProvider*) self)
     goto out;
 
   g_object_notify (G_OBJECT (self), "default-task-list");
@@ -528,22 +536,6 @@ gtd_provider_eds_load_registry (GtdProviderEds  *provider)
   e_credentials_prompter_process_awaiting_credentials (priv->credentials_prompter);
 }
 
-static gboolean
-gtd_provider_eds_try_load (GtdProviderEds *provider)
-{
-  GtdProviderEdsPrivate *priv = gtd_provider_eds_get_instance_private (provider);
-
-  if (gtd_object_get_ready (GTD_OBJECT (provider)))
-    {
-      gtd_provider_eds_load_registry (provider);
-      priv->lazy_load_id = 0;
-
-      return G_SOURCE_REMOVE;
-    }
-
-  return G_SOURCE_CONTINUE;
-}
-
 static void
 gtd_provider_eds_set_registry (GtdProviderEds  *provider,
                                ESourceRegistry *registry)
@@ -552,9 +544,7 @@ gtd_provider_eds_set_registry (GtdProviderEds  *provider,
 
   g_set_object (&priv->source_registry, registry);
 
-  priv->lazy_load_id = g_timeout_add (250,
-                                      (GSourceFunc) gtd_provider_eds_try_load,
-                                      provider);
+  gtd_provider_eds_load_registry (provider);
 }
 
 
@@ -589,7 +579,9 @@ gtd_provider_eds_create_task_finished (GObject      *client,
       /* Display a notification */
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error creating task"),
-                                      error->message);
+                                      error->message,
+                                      NULL,
+                                      NULL);
 
       g_error_free (error);
     }
@@ -633,7 +625,9 @@ gtd_provider_eds_update_task_finished (GObject      *client,
 
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error updating task"),
-                                      error->message);
+                                      error->message,
+                                      NULL,
+                                      NULL);
 
       g_error_free (error);
     }
@@ -669,7 +663,9 @@ gtd_provider_eds_remove_task_finished (GObject      *client,
 
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error removing task"),
-                                      error->message);
+                                      error->message,
+                                      NULL,
+                                      NULL);
       g_error_free (error);
       return;
     }
@@ -697,7 +693,9 @@ gtd_provider_eds_remote_create_source_finished (GObject      *source,
 
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error creating task list"),
-                                      error->message);
+                                      error->message,
+                                      NULL,
+                                      NULL);
       g_clear_error (&error);
     }
 }
@@ -720,7 +718,9 @@ task_list_removal_finished (GtdProvider *provider,
 
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error removing task list"),
-                                      (*error)->message);
+                                      (*error)->message,
+                                      NULL,
+                                      NULL);
       g_clear_error (error);
     }
 }
@@ -781,7 +781,9 @@ gtd_provider_eds_commit_source_finished (GObject      *registry,
 
       gtd_manager_emit_error_message (gtd_manager_get_default (),
                                       _("Error saving task list"),
-                                      error->message);
+                                      error->message,
+                                      NULL,
+                                      NULL);
       g_error_free (error);
       return;
     }
